@@ -7,30 +7,34 @@
 #' The household consumes products and supplies labor.
 #' @param input the input matrix in the base period.
 #' @param output a vector consisting of the product outputs and labor supply in the base period.
-#' @param sigma a scalar, which is the coefficient of elasticity of substitution between the
-#' inputs. 1/(1-sigma) is the elasticity of substitution.
+#' @param es a scalar, which is the elasticity of substitution between the
+#' inputs.
 #' @return A general equilibrium.
 #' @references Zhang Xin. (2017, ISBN: 9787543227637). Principles of Computable General Equilibrium Modeling and Programming (Second Edition). Shanghai: Gezhi Press. (In Chinese)
 #' @examples
 #' x <- 75
-#' gemInputOutputTable_CES_3_3(input = matrix(c(
-#'   200, 300, 100,
-#'   x, 320, 530,
-#'   250, 380, 0
-#' ), 3, 3, TRUE), output = c(600, 1000, 630), sigma = -1)
+#' gemInputOutputTable_CES_3_3(
+#'   input = matrix(c(
+#'     200, 300, 100,
+#'     x, 320, 530,
+#'     250, 380, 0
+#'   ), 3, 3, TRUE),
+#'   output = c(600, 1000, 630),
+#'   es = 0.5
+#' )
 
 gemInputOutputTable_CES_3_3 <- function(input = matrix(c(
-                                               200, 300, 100,
-                                               150, 320, 530,
-                                               250, 380, 0
-                                             ), 3, 3, TRUE), output = c(600, 1000, 630),
-                                             sigma = -Inf) {
-
+                                          200, 300, 100,
+                                          150, 320, 530,
+                                          250, 380, 0
+                                        ), 3, 3, TRUE),
+                                        output = c(600, 1000, 630),
+                                        es = 0) {
   Beta <- prop.table(input, 2)
-  alpha <- output/colSums(input)
+  alpha <- output / colSums(input)
   ge <- sdm(
-    A = function(state){
-      SCES_A(sigma=rep(sigma,3), alpha=alpha, Beta=Beta, p=state$p)
+    A = function(state) {
+      SCES_A(alpha = alpha, Beta = Beta, p = state$p, es = rep(es, 3))
     },
     B = diag(3),
     S0Exg = {
